@@ -1,3 +1,23 @@
+"""
+This file is part of xapers.
+
+Xapers is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the
+Free Software Foundation, either version 3 of the License, or (at your
+option) any later version.
+
+Xapers is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License
+along with xapers.  If not, see <http://www.gnu.org/licenses/>.
+
+Copyright 2012-2017
+Jameson Rollins <jrollins@finestructure.net>
+"""
+
 import os
 
 ##################################################
